"""gui.py

画面周りを作成、表示する関数群です。
全体のメイン関数があります。

Copyright (C) 2024 UNION SYSTEM Inc.

"""
from tkinter import ttk, filedialog, messagebox
import tkinter as tk
import ss7_to_csv as ss7
DATA1, DATA2 = 0, 1


class InpWindow:
    """InpWindow

    入力画面を管理するクラスです。

    """
    # コンストラクタ
    def __init__(self) -> None:
        """__init__

        InpWindowクラスの初期化関数です。

        """
        self.root = tk.Tk()
        self.file_path: list[str] = ["", ""]
        self.file_name = ""

    # パスのセット
    def set_path(self, file_path: str, num: int) -> None:
        """set_path

        InpInfoクラスに物件パスをセットする関数です。

        Args:
            file_path(str):物件のパス
            num(int):0 = 反映元データ , 1 = 反映先データ

        """
        self.file_path[num] = file_path

    def file_select(self, textbox: tk.Entry, num: int) -> None:
        """file_select

        テキストボックスに選択したフォルダを出力する関数です。
        画面の"・・・"ボタンをクリックするとこの関数が実行されます。

        Args:
            textbox(tk.Entry):画面に出力されているテキストボックス
            num(int):0 = 反映元データ , 1 = 反映先データ

        """
        idir: str = "C:\\"  # 初期フォルダ
        file_path: str = filedialog.askdirectory(initialdir=idir)
        textbox.insert(tk.END, file_path)  # 結果を表示
        # 入力情報のセット
        self.set_path(file_path, num)

    def f_text(self, name: str, row: int, column: int,
               num: int = -1, flg: bool = True) -> None:
        """f_text

        パスを入力するテキストボックスをウィンドウに配置する関数です。

        Args:
            name(str):ラベル名
            row(int):配置行
            column(int):配置列
            num(int):0 = 反映元データ , 1 = 反映先データ
            flg(bool):ボタン作成するかどうかのフラグ

        """
        # パスの入力
        frame1: tk.Frame = tk.Frame(self.root, width=370, height=30)
        frame1.pack_propagate(False)
        # ラベルの作成
        tk.Label(frame1, text=name).pack(side="left", padx=1)
        # 入力の作成
        textbox: tk.Entry = tk.Entry(frame1, width=40)
        textbox.pack(side="left", padx=5)
        if flg:
            # ボタンの作成
            tk.Button(frame1, text="・・・",
                      command=lambda: self.file_select(textbox, num),
                      width=3).pack(side="right", padx=1)
        else:
            self.textbox = textbox
        # フレームの配置
        frame1.grid(row=row, column=column)  # frame1を配置
        frame1.update_idletasks()

    def btn(self, row: int, column: int) -> None:
        """btn

        実行, キャンセルボタンを配置する関数です。

        Args:
            row(int):配置行
            column(int):配置列

        """
        # 実行ボタン
        frm: tk.Frame = tk.Frame(self.root, width=370, height=30)
        frm.pack_propagate(False)
        # ボタンの作成
        ttk.Button(frm, text="実行",
                   command=lambda: self.btn_click_execute()).pack(side="right", padx=5)
        ttk.Button(frm, text="キャンセル",
                   command=lambda: self.btn_click_cancel()).pack(side="right")
        # フレームの配置
        frm.grid(row=row, column=column)

    def btn_click_cancel(self) -> None:
        """btn_click_cancel

        キャンセルボタンをクリックしたとき場合に起動する関数です。

        """
        # 閉じる
        if messagebox.askokcancel("確認", "本当に閉じていいですか？"):
            self.root.destroy()

    def btn_click_execute(self) -> None:
        """btn_click_execute

        比較ボタンをクリックしたとき場合に起動する関数です。

        """
        # パスの取得
        if self.file_path[0] == "" or self.file_path[1] == "":
            messagebox.askokcancel("確認", "ファイルが未選択です。")
            return
        # 実行関数
        self.execute()

    def start(self) -> None:
        """start

        ウィンドウを起動する関数です。

        """
        self.root.title("")
        self.f_text("反映元データ", 0, 0, DATA1)
        self.f_text("反映先データ", 1, 0, DATA2)
        self.f_text("生成する物件名", 2, 0, flg=False)
        self.btn(3, 0)
        self.root.mainloop()

    def execute(self) -> None:
        """execute

        実行ボタンクリック時の関数です。

        """
        # csvを出力
        path = (self.file_path[0], self.file_path[1])
        ss7.create_main(path, self.textbox.get())
        return


if __name__ == "__main__":
    """main

    メイン関数です。
    """
    # 入力情報クラス
    win: InpWindow = InpWindow()
    win.start()
